@@ -1,16 +1,19 @@
 import platform
 import subprocess as sps
 import sys
+from typing import List
 
-name = 'Edge'
+from eel.types import OptionsDictT
+
+name: str = 'Edge'
 
 
-def run(_path, options, start_urls):
+def run(_path: str, options: OptionsDictT, start_urls: List[str]) -> None:
     cmd = 'start microsoft-edge:{}'.format(start_urls[0])
     sps.Popen(cmd, stdout=sys.stdout, stderr=sys.stderr, stdin=sps.PIPE, shell=True)
 
 
-def find_path():
+def find_path() -> bool:
     if platform.system() == 'Windows':
         return True
 
